@@ -1,5 +1,6 @@
 from datetime import datetime
 from datetime import date
+from time import time
 
 
 def fake_datetime_function():
@@ -8,3 +9,7 @@ def fake_datetime_function():
 
 def fake_date_function():
     return date.today()
+
+
+def fake_time_function():
+    return time()
